package com.jz.dmp.modules.controller.sys;

import javax.servlet.http.HttpServletRequest;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.jz.common.bean.BaseBeanResponse;
import com.jz.common.bean.BaseResponse;
import com.jz.common.bean.PageInfoResponse;
import com.jz.common.constant.ResultCode;
import com.jz.dmp.modules.controller.sys.bean.DmpMemberBatch;
import com.jz.dmp.modules.controller.sys.bean.DmpMemberDto;
import com.jz.dmp.modules.controller.sys.bean.DmpMemberRequest;
import com.jz.dmp.modules.model.DmpMember;
import com.jz.dmp.modules.service.sys.DmpMemberService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

/**
 * 用户表Controller
 * @author ybz
 *
 */
@RestController
@RequestMapping("/dmp/member")
@Api(tags = "用户表")
public class DmpMemberController {
	
	@Autowired
	private DmpMemberService dmpMemberService;
	
	/**列表查询用户表
	 * @param dmpMemberRequest
	 * @return
	 */
	@RequestMapping(method = RequestMethod.POST, value = "/findList")
	@ApiOperation(value = "列表查询用户表", notes = "列表查询用户表")
	public PageInfoResponse<DmpMemberDto> findList(@RequestBody DmpMemberRequest dmpMemberRequest, HttpServletRequest httpRequest){
		PageInfoResponse<DmpMemberDto> pageInfo = new PageInfoResponse<DmpMemberDto>();
		try {
			pageInfo = dmpMemberService.findList(dmpMemberRequest, httpRequest);
		} catch (Exception e) {
			pageInfo.setMessage("查询失败");
			pageInfo.setCode(ResultCode.INTERNAL_SERVER_ERROR.val());
			e.printStackTrace();
		}
		
		return pageInfo;
	}
	
	
	/**主键查询用户表
	 * @param dmpMemberRequest
	 * @return
	 */
	@RequestMapping(method = RequestMethod.POST, value = "/view")
	@ApiOperation(value = "主键查询用户表", notes = "主键查询用户表")
	public BaseBeanResponse<DmpMemberDto> view(@RequestBody DmpMemberRequest dmpMemberRequest, HttpServletRequest httpRequest){
		BaseBeanResponse<DmpMemberDto> baseBeanResponse = new BaseBeanResponse<DmpMemberDto>();
		try {
			baseBeanResponse = dmpMemberService.findById(dmpMemberRequest, httpRequest);
		} catch (Exception e) {
			baseBeanResponse.setMessage("请求失败");
			baseBeanResponse.setCode(ResultCode.INTERNAL_SERVER_ERROR.val());
			e.printStackTrace();
		}
		
		return baseBeanResponse;
	}
	
	/**删除用户表
	 * @param dmpMemberRequest
	 * @return
	 */
	@RequestMapping(method = RequestMethod.POST, value = "/delete")
	@ApiOperation(value = "删除用户表", notes = "删除用户表")
	public BaseResponse delete(@RequestBody DmpMemberRequest dmpMemberRequest, HttpServletRequest httpRequest){
		BaseResponse baseResponse = new BaseResponse();
		try {
			baseResponse = dmpMemberService.deleteById(dmpMemberRequest, httpRequest);
		} catch (Exception e) {
			baseResponse.setMessage("删除失败");
			baseResponse.setCode(ResultCode.INTERNAL_SERVER_ERROR.val());
			e.printStackTrace();
		}
		
		return baseResponse;
	}
	
	/**新增用户表
	 * @param dmpMemberRequest
	 * @return
	 */
	@RequestMapping(method = RequestMethod.POST, value = "/add")
	@ApiOperation(value = "新增用户表", notes = "新增用户表")
	public BaseBeanResponse<DmpMember> add(@RequestBody DmpMember dmpMember, HttpServletRequest httpRequest){
		BaseBeanResponse<DmpMember> baseBeanResponse = new BaseBeanResponse<DmpMember>();
		try {
			baseBeanResponse = dmpMemberService.add(dmpMember, httpRequest);
		} catch (Exception e) {
			baseBeanResponse.setMessage("新增失败");
			baseBeanResponse.setCode(ResultCode.INTERNAL_SERVER_ERROR.val());
			e.printStackTrace();
		}
		
		return baseBeanResponse;
	}
	
	/**批量新增用户表
	 * @param dmpMemberRequest
	 * @return
	 */
	@RequestMapping(method = RequestMethod.POST, value = "/addBatch")
	@ApiOperation(value = "批量新增用户表", notes = "批量新增用户表")
	public BaseBeanResponse<DmpMemberBatch> addBatch(@RequestBody DmpMemberBatch dmpMemberBatch, HttpServletRequest httpRequest){
		BaseBeanResponse<DmpMemberBatch> baseBeanResponse = new BaseBeanResponse<DmpMemberBatch>();
		try {
			baseBeanResponse = dmpMemberService.addBatch(dmpMemberBatch, httpRequest);
		} catch (Exception e) {
			baseBeanResponse.setMessage("批量新增失败");
			baseBeanResponse.setCode(ResultCode.INTERNAL_SERVER_ERROR.val());
			e.printStackTrace();
		}
		
		return baseBeanResponse;
	}
	
	/**修改用户表
	 * @param dmpMemberRequest
	 * @return
	 */
	@RequestMapping(method = RequestMethod.POST, value = "/edit")
	@ApiOperation(value = "修改用户表", notes = "修改用户表")
	public BaseBeanResponse<DmpMember> edit(@RequestBody DmpMember dmpMember, HttpServletRequest httpRequest){
		BaseBeanResponse<DmpMember> baseBeanResponse = new BaseBeanResponse<DmpMember>();
		try {
			baseBeanResponse = dmpMemberService.edit(dmpMember, httpRequest);
		} catch (Exception e) {
			baseBeanResponse.setMessage("修改失败");
			baseBeanResponse.setCode(ResultCode.INTERNAL_SERVER_ERROR.val());
			e.printStackTrace();
		}
		
		return baseBeanResponse;
	}
	
}
