package com.jz.dmp.modules.service.impl;

import com.jz.dmp.modules.dao.DmpNavigationTreeDao;
import com.jz.dmp.modules.model.DmpNavigationTree;
import com.jz.dmp.modules.service.DmpNavigationTreeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * DMP资源导航树(DmpNavigationTree)表服务实现类
 *
 * @author Bellamy
 * @since 2020-12-29 15:08:16
 */
@Service("dmpNavigationTreeService")
public class DmpNavigationTreeServiceImpl implements DmpNavigationTreeService {

    @Autowired
    private DmpNavigationTreeDao dmpNavigationTreeDao;

    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    @Override
    public DmpNavigationTree queryById(Integer id) {
        return this.dmpNavigationTreeDao.queryById(id);
    }

    /**
     * 查询多条数据
     *
     * @param offset 查询起始位置
     * @param limit  查询条数
     * @return 对象列表
     */
    @Override
    public List<DmpNavigationTree> queryAllByLimit(int offset, int limit) {
        return this.dmpNavigationTreeDao.queryAllByLimit(offset, limit);
    }

    /**
     * 新增数据
     *
     * @param dmpNavigationTree 实例对象
     * @return 实例对象
     */
    @Override
    public DmpNavigationTree insert(DmpNavigationTree dmpNavigationTree) {
        this.dmpNavigationTreeDao.insert(dmpNavigationTree);
        return dmpNavigationTree;
    }

    /**
     * 修改数据
     *
     * @param dmpNavigationTree 实例对象
     * @return 实例对象
     */
    @Override
    public DmpNavigationTree update(DmpNavigationTree dmpNavigationTree) {
        this.dmpNavigationTreeDao.update(dmpNavigationTree);
        return this.queryById(dmpNavigationTree.getId());
    }

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @Override
    public boolean deleteById(Integer id) {
        return this.dmpNavigationTreeDao.deleteById(id) > 0;
    }
}