package com.jz.dmp.modules.service.sys.impl;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import javax.servlet.http.HttpServletRequest;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;
import org.springframework.util.StringUtils;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.jz.common.bean.BaseBeanResponse;
import com.jz.common.bean.BaseResponse;
import com.jz.common.bean.PageInfoResponse;
import com.jz.common.constant.Constants;
import com.jz.common.constant.ResultCode;
import com.jz.common.persistence.BaseService;
import com.jz.dmp.modules.controller.sys.bean.DmpRoleBatch;
import com.jz.dmp.modules.controller.sys.bean.DmpRoleDto;
import com.jz.dmp.modules.controller.sys.bean.DmpRoleRequest;
import com.jz.dmp.modules.dao.sys.DmpRoleMapper;
import com.jz.dmp.modules.model.DmpRole;
import com.jz.dmp.modules.service.sys.DmpRoleService;

/**
 * 角色表服务的实现?
 * @author ybz
 *
 */
@Service("dmpRoleService")
public class DmpRoleServiceImpl extends BaseService implements DmpRoleService {
	
	private static Logger logger = LoggerFactory.getLogger(DmpRoleServiceImpl.class);
	
	@Autowired
	private DmpRoleMapper dmpRoleMapper;

	/* (non-Javadoc)
	 * @see com.ycxc.vmts.service.DmpRoleService#findList(com.ycxc.vmts.controller.bean.DmpRoleRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	public PageInfoResponse<DmpRoleDto> findList(DmpRoleRequest dmpRoleRequest, HttpServletRequest httpRequest)
			throws Exception {
		PageInfoResponse<DmpRoleDto> pageInfoResponse = new PageInfoResponse<>();
		
		Map<String, Object> param = new HashMap<>();
		//角色ID
		if (dmpRoleRequest.getRoleId() != null) {
			param.put("roleId", dmpRoleRequest.getRoleId());
		}
		//角色编码
		if (!StringUtils.isEmpty(dmpRoleRequest.getRoleCode())) {
			param.put("roleCode", dmpRoleRequest.getRoleCode());
		}
		//角色名称
		if (!StringUtils.isEmpty(dmpRoleRequest.getRoleName())) {
			param.put("roleName", dmpRoleRequest.getRoleName());
		}
		//角色描述
		if (!StringUtils.isEmpty(dmpRoleRequest.getRoleDesc())) {
			param.put("roleDesc", dmpRoleRequest.getRoleDesc());
		}
		//角色类型
		if (!StringUtils.isEmpty(dmpRoleRequest.getRoleType())) {
			param.put("roleType", dmpRoleRequest.getRoleType());
		}
		//备注
		if (!StringUtils.isEmpty(dmpRoleRequest.getRemark())) {
			param.put("remark", dmpRoleRequest.getRemark());
		}
		//数据状态(0：删除，1，未删除)
		if (!StringUtils.isEmpty(dmpRoleRequest.getDataStatus())) {
			param.put("dataStatus", dmpRoleRequest.getDataStatus());
		}
		//创建用户ID
		if (dmpRoleRequest.getCreateUserId() != null) {
			param.put("createUserId", dmpRoleRequest.getCreateUserId());
		}
		//创建时间起
		if (dmpRoleRequest.getCreateTimeStart() != null) {
			param.put("createTimeStart", dmpRoleRequest.getCreateTimeStart());
		}
		//创建时间止
		if (dmpRoleRequest.getCreateTimeEnd() != null) {
			param.put("createTimeEnd", dmpRoleRequest.getCreateTimeEnd());
		}
		//修改用户ID
		if (dmpRoleRequest.getUpdateUserId() != null) {
			param.put("updateUserId", dmpRoleRequest.getUpdateUserId());
		}
		//修改时间起
		if (dmpRoleRequest.getUpdateTimeStart() != null) {
			param.put("updateTimeStart", dmpRoleRequest.getUpdateTimeStart());
		}
		//修改时间止
		if (dmpRoleRequest.getUpdateTimeEnd() != null) {
			param.put("updateTimeEnd", dmpRoleRequest.getUpdateTimeEnd());
		}
		
		PageHelper.startPage(dmpRoleRequest.getPageNum(), dmpRoleRequest.getPageSize());
		List<DmpRoleDto> list = dmpRoleMapper.findList(param);
		PageInfo<DmpRoleDto> pageInfo = new PageInfo<>(list);
		
		pageInfoResponse.setCode(ResultCode.SUCCESS.val());
		pageInfoResponse.setMessage("查询成功");
		pageInfoResponse.setData(pageInfo);
		return pageInfoResponse;
	}
	

	/* (non-Javadoc)
	 * @see com.ycxc.vmts.service.DmpRoleService#add(com.ycxc.vmts.entity.DmpRole, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor=Exception.class)
	public BaseBeanResponse<DmpRole> add(DmpRole dmpRole, HttpServletRequest httpRequest) throws Exception {
		BaseBeanResponse<DmpRole> baseBeanResponse = new BaseBeanResponse<>();
		
		/*$*setRoleIdCodeReplace*$*/
		//创建人
		dmpRole.setCreateUserId(getHttpRequestUserId(httpRequest));
		//创建时间
		dmpRole.setCreateTime(new Date());
		
		dmpRoleMapper.insertSelective(dmpRole);
		
		baseBeanResponse.setCode(ResultCode.SUCCESS.val());
		baseBeanResponse.setMessage("新增成功");
		baseBeanResponse.setData(dmpRole);
		
		return baseBeanResponse;
	}

	/* (non-Javadoc)
	 * @see com.ycxc.vmts.service.DmpRoleService#edit(com.ycxc.vmts.entity.DmpRole, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor=Exception.class)
	public BaseBeanResponse<DmpRole> edit(DmpRole dmpRole, HttpServletRequest httpRequest) throws Exception {
		BaseBeanResponse<DmpRole> baseBeanResponse = new BaseBeanResponse<>();
		
		//修改人
		dmpRole.setUpdateUserId(getHttpRequestUserId(httpRequest));
		//修改时间
		dmpRole.setUpdateTime(new Date());
		
		dmpRoleMapper.updateByPrimaryKeySelective(dmpRole);
		
		baseBeanResponse.setCode(ResultCode.SUCCESS.val());
		baseBeanResponse.setMessage("修改成功");
		baseBeanResponse.setData(dmpRole);
		
		return baseBeanResponse;
	}

	/* (non-Javadoc)
	 * @see com.ycxc.vmts.service.DmpRoleService#findById(com.ycxc.vmts.controller.bean.DmpRoleRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	public BaseBeanResponse<DmpRoleDto> findById(DmpRoleRequest dmpRoleRequest, HttpServletRequest httpRequest)
			throws Exception {
		BaseBeanResponse<DmpRoleDto> baseBeanResponse = new BaseBeanResponse<>();
		
		DmpRoleDto dmpRoleDto = dmpRoleMapper.findById(dmpRoleRequest.getRoleId());
		
		baseBeanResponse.setCode(ResultCode.SUCCESS.val());
		baseBeanResponse.setMessage("查询成功");
		baseBeanResponse.setData(dmpRoleDto);
		
		return baseBeanResponse;
	}

	/* (non-Javadoc)
	 * @see com.ycxc.vmts.service.DmpRoleService#deleteById(com.ycxc.vmts.controller.bean.DmpRoleRequest, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor=Exception.class)
	public BaseResponse deleteById(DmpRoleRequest dmpRoleRequest, HttpServletRequest httpRequest)
			throws Exception {
		BaseResponse baseResponse = new BaseResponse();
		
		dmpRoleMapper.deleteByPrimaryKey(dmpRoleRequest.getRoleId());
		
		baseResponse.setCode(ResultCode.SUCCESS.val());
		baseResponse.setMessage("删除成功");
		
		return baseResponse;
	}

	/* (non-Javadoc)
	 * @see com.ycxc.vmts.service.DmpRoleService#addBatch(com.ycxc.vmts.controller.bean.DmpRoleVo, javax.servlet.http.HttpServletRequest)
	 */
	@Override
	@Transactional(rollbackFor=Exception.class)
	public BaseBeanResponse<DmpRoleBatch> addBatch(DmpRoleBatch dmpRoleBatch, HttpServletRequest httpRequest) throws Exception {
		BaseBeanResponse<DmpRoleBatch> baseBeanResponse = new BaseBeanResponse<>();
		
		List<DmpRole> dmpRoles = dmpRoleBatch.getDmpRoles();
		
		if (CollectionUtils.isEmpty(dmpRoles)) {
			baseBeanResponse.setCode(ResultCode.PARAMS_ERROR.val());
			baseBeanResponse.setMessage("数据不能为空！");
			return baseBeanResponse;
		}
		
		dmpRoles = dmpRoles.stream().map(dmpRole -> {
			/*$*setRoleIdCodeReplace*$*/
			//创建人
			try {
				dmpRole.setCreateUserId(getHttpRequestUserId(httpRequest));
			} catch (Exception e) {
				logger.info(e.getMessage());
				e.printStackTrace();
			}
			//创建时间
			dmpRole.setCreateTime(new Date());
			
			return dmpRole;
		}).collect(Collectors.toList());
		
		dmpRoleMapper.insertBatch(dmpRoles);
		
		baseBeanResponse.setCode(ResultCode.SUCCESS.val());
		baseBeanResponse.setMessage("批量新增成功");
		baseBeanResponse.setData(dmpRoleBatch);
		
		return baseBeanResponse;
	}
	
}
